==> marketplace-constants-0.1.4.8.tar.gz: marketplace-constants-0.1.4.8/mpconstants/regions/gl.py <==
REGIONS = {u'ad': u'Andorra',
 u'ae': u'E.A.U.',
 u'af': u'Afganist\xe1n',
 u'ag': u'Antigua e Barbuda',
 u'ai': u'Anguila',
 u'al': u'Albania',
 u'am': u'Armenia',
 u'an': u'Antillas Neerlandesas ou Holandesas',
 u'ao': u'Angola',
 u'aq': u'Ant\xe1rtida',
 u'ar': u'Arxentina',
 u'as': u'Samoa americana',
 u'at': u'Austria',
 u'au': u'Australia',
 u'aw': u'Aruba',
 u'ax': u'Illas de \\u00c5land',
 u'az': u'Acerbaix\xe1n',
 u'ba': u'Bosnia-Hercegovina',
 u'bb': u'Barbados',
 u'bd': u'Bangladesh',
 u'be': u'B\xe9lxica',
 u'bf': u'Burkina Faso',
 u'bg': u'Bulgaria',
 u'bh': u'Bahrain',
 u'bi': u'Burundi',
 u'bj': u'Benin',
 u'bl': u'San Bartolomeo',
 u'bm': u'Bermudas',
 u'bn': u'Brunei Darussalam',
 u'bo': u'Bolivia',
 u'br': u'Brasil',
 u'bs': u'Bahamas',
 u'bt': u'But\xe1n',
 u'bv': u'Illa Bouvet',
 u'bw': u'Bostwana',
 u'by': u'Bielorrusia',
 u'bz': u'Belize',
 u'ca': u'Canad\xe1',
 u'cc': u'Illas Cocos ou Keeling',
 u'cd': u'Rep\xfablica Democr\xe1tica do Congo-Kinshasa',
 u'cf': u'Rep\xfablica Centroafricana',
 u'cg': u'Congo-Brazzaville',
 u'ch': u'Su\xedza',
 u'ci': u'Costa do Marfil',
 u'ck': u'Illas Cook',
 u'cl': u'Chile',
 u'cm': u'Camer\xfan',
 u'cn': u'China',
 u'co': u'Colombia',
 u'cr': u'Costa Rica',
 u'cu': u'Cuba',
 u'cv': u'Cabo Verde',
 u'cx': u'Illa de Christmas',
 u'cy': u'Chipre',
 u'cz': u'Rep\xfablica Checa',
 u'de': u'Alema\xf1a',
 u'dj': u'Djibuti',
 u'dk': u'Dinamarca',
 u'dm': u'Dominica',
 u'do': u'Rep\xfablica Dominicana',
 u'dz': u'Alxeria',
 u'ec': u'Ecuador',
 u'ee': u'Estonia',
 u'eg': u'Exipto',
 u'eh': u'S\xe1hara Occidental',
 u'er': u'Eritrea',
 u'es': u'Espa\xf1a',
 u'et': u'Etiop\xeda',
 u'fi': u'Finlandia',
 u'fj': u'Fixi',
 u'fk': u'Illas Malvinas ou Falkland',
 u'fm': u'Micronesia',
 u'fo': u'Illas Feroe',
 u'fr': u'Francia',
 u'ga': u'Gab\xf3n',
 u'gb': u'Reino Unido',
 u'gd': u'Granada',
 u'ge': u'Xeorxia',
 u'gf': u'G\xfciana Francesa',
 u'gg': u'Guernsey',
 u'gh': u'Gana',
 u'gi': u'Xibraltar',
 u'gl': u'Groenlandia',
 u'gm': u'Gambia',
 u'gn': u'Guinea',
 u'gp': u'Guadalupe',
 u'gq': u'Guinea Ecuatorial',
 u'gr': u'Grecia',
 u'gs': u'Xeorxia do Sur e Illas S\xe1ndwich do Sur',
 u'gt': u'Guatemala',
 u'gu': u'Guam',
 u'gw': u'Guinea-Bissau',
 u'gy': u'G\xfciana',
 u'hk': u'Hong Kong',
 u'hm': u'Illas Heard e McDonald',
 u'hn': u'Honduras',
 u'hr': u'Croacia',
 u'ht': u'Hait\xed',
 u'hu': u'Hungr\xeda',
 u'id': u'Indonesia',
 u'ie': u'Irlanda',
 u'il': u'Israel',
 u'im': u'Illa de Man',
 u'in': u'India',
 u'io': u'Territorio Brit\xe1nico do oc\xe9ano \xcdndico',
 u'iq': u'Iraq',
 u'ir': u'Ir\xe1n',
 u'is': u'Islandia',
 u'it': u'Italia',
 u'je': u'Jersey',
 u'jm': u'Xamaica',
 u'jo': u'Xordania',
 u'jp': u'Xap\xf3n',
 u'ke': u'Kenya',
 u'kg': u'Kirguizist\xe1n',
 u'kh': u'Cambodia',
 u'ki': u'Kiribati',
 u'km': u'Comores',
 u'kn': u'San Cristovo-Nevis',
 u'kp': u'Corea do Norte',
 u'kr': u'Corea do Sur',
 u'kw': u'Kuwait',
 u'ky': u'Illas Caim\xe1n',
 u'kz': u'Kazakhist\xe1n',
 u'la': u'Laosme',
 u'lb': u'L\xedbano',
 u'lc': u'Santa Luc\xeda',
 u'li': u'Liechtenstein',
 u'lk': u'Sri Lanka',
 u'lr': u'Liberia',
 u'ls': u'Lesotho',
 u'lt': u'Lituania',
 u'lu': u'Luxemburgo',
 u'lv': u'Letonia',
 u'ly': u'Libia',
 u'ma': u'Marrocos',
 u'mc': u'M\xf3naco',
 u'md': u'Moldavia',
 u'me': u'Montenegro',
 u'mf': u'Illa de San Marti\xf1o',
 u'mg': u'Madagascar',
 u'mh': u'Illas Marshall',
 u'mk': u'Rep\xfablica de Macedonia',
 u'ml': u'Mal\xed',
 u'mm': u'Myanmar',
 u'mn': u'Mongolia',
 u'mo': u'Macau',
 u'mp': u'Illas Marianas do Norte',
 u'mq': u'Martinica',
 u'mr': u'Mauritania',
 u'ms': u'Montserrat',
 u'mt': u'Malta',
 u'mu': u'Mauricio',
 u'mv': u'Maldivas',
 u'mw': u'Malawi',
 u'mx': u'M\xe9xico',
 u'my': u'Malaisia',
 u'mz': u'Mozambique',
 u'na': u'Namibia',
 u'nc': u'Nova Caledonia',
 u'ne': u'N\xedxer',
 u'nf': u'Illa de Norfolk',
 u'ng': u'Nixeria',
 u'ni': u'Nicaragua',
 u'nl': u'Pa\xedses Baixos',
 u'no': u'Noruega',
 u'np': u'Nepal',
 u'nr': u'Nauruano',
 u'nu': u'Niue',
 u'nz': u'Nova Zelandia',
 u'om': u'Om\xe1n',
 u'pa': u'Panam\xe1',
 u'pe': u'Per\xfa',
 u'pf': u'Polinesia Francesa',
 u'pg': u'Pap\xfaa-Nova Guinea',
 u'ph': u'Filipinas',
 u'pk': u'Paquist\xe1n',
 u'pl': u'Polonia',
 u'pm': u'Saint Pierre e Miquelon',
 u'pn': u'Illas Pitcairn',
 u'pr': u'Porto Rico',
 u'ps': u'Territorio palestino ocupado',
 u'pt': u'Portugal',
 u'pw': u'Palau',
 u'py': u'Paraguai',
 u'qa': u'Qatar',
 u're': u'Reuni\xf3n',
 u'ro': u'Roman\xeda',
 u'rs': u'Serbia',
 u'ru': u'Federaci\xf3n rusa',
 u'rw': u'Ruanda',
 u'sa': u'Arabia Saud\xed',
 u'sb': u'Illas Salom\xf3n',
 u'sc': u'Seicheles',
 u'sd': u'Sud\xe1n',
 u'se': u'Suecia',
 u'sg': u'Singapur',
 u'sh': u'Santa Helena',
 u'si': u'Eslovenia',
 u'sj': u'Svalbard e Jan Mayen',
 u'sk': u'Eslovaquia',
 u'sl': u'Serra Leoa',
 u'sm': u'San Marino',
 u'sn': u'Senegal',
 u'so': u'Somalia',
 u'sr': u'Suriname',
 u'st': u'San Tom\xe9 e Pr\xedncipe',
 u'sv': u'O Salvador',
 u'sy': u'Siria',
 u'sz': u'Suazilandia',
 u'tc': u'Illas Caicos e Turcas',
 u'td': u'Chad',
 u'tf': u'Territorios Franceses do Sur',
 u'tg': u'Togo',
 u'th': u'Tailandia',
 u'tj': u'Taxiquist\xe1n',
 u'tk': u'Tokelau',
 u'tl': u'Timor-Leste',
 u'tm': u'Turkmenist\xe1n',
 u'tn': u'Tunisia',
 u'to': u'Tonga',
 u'tr': u'Turqu\xeda',
 u'tt': u'Trinidad e Tobago',
 u'tv': u'Tuvalu',
 u'tw': u'Taiw\xe1n',
 u'tz': u'Tanzania',
 u'ua': u'Ucra\xedna',
 u'ug': u'Uganda',
 u'um': u'Illas perif\xe9ricas dos Estados Unidos',
 u'us': u'Estados Unidos',
 u'uy': u'Uruguai',
 u'uz': u'Uzbequist\xe1n',
 u'va': u'Cidade do Vaticano',
 u'vc': u'San Vicente e as Granadinas',
 u've': u'Venezuela',
 u'vg': u'Illas Virxes brit\xe1nicas',
 u'vi': u'Illas Virxes americanas',
 u'vn': u'Vietnam',
 u'vu': u'Vanuatu',
 u'wf': u'Wallis e Futuna',
 u'ws': u'Samoa',
 u'ye': u'Iemen',
 u'yt': u'Mayotte',
 u'za': u'Sur\xe1frica',
 u'zm': u'Zambia',
 u'zw': u'Cimbabue'}

==> marketplace-constants-0.3.1.tar.gz: marketplace-constants-0.3.1/mpconstants/regions/gl.py <==
REGIONS = {u'ad': u'Andorra',
 u'ae': u'E.A.U.',
 u'af': u'Afganist\xe1n',
 u'ag': u'Antigua e Barbuda',
 u'ai': u'Anguila',
 u'al': u'Albania',
 u'am': u'Armenia',
 u'an': u'Antillas Neerlandesas ou Holandesas',
 u'ao': u'Angola',
 u'aq': u'Ant\xe1rtida',
 u'ar': u'Arxentina',
 u'as': u'Samoa americana',
 u'at': u'Austria',
 u'au': u'Australia',
 u'aw': u'Aruba',
 u'ax': u'Illas de \xc5land',
 u'az': u'Acerbaix\xe1n',
 u'ba': u'Bosnia-Hercegovina',
 u'bb': u'Barbados',
 u'bd': u'Bangladesh',
 u'be': u'B\xe9lxica',
 u'bf': u'Burkina Faso',
 u'bg': u'Bulgaria',
 u'bh': u'Bahrain',
 u'bi': u'Burundi',
 u'bj': u'Benin',
 u'bl': u'San Bartolomeo',
 u'bm': u'Bermudas',
 u'bn': u'Brunei Darussalam',
 u'bo': u'Bolivia',
 u'br': u'Brasil',
 u'bs': u'Bahamas',
 u'bt': u'But\xe1n',
 u'bv': u'Illa Bouvet',
 u'bw': u'Bostwana',
 u'by': u'Bielorrusia',
 u'bz': u'Belize',
 u'ca': u'Canad\xe1',
 u'cc': u'Illas Cocos ou Keeling',
 u'cd': u'Rep\xfablica Democr\xe1tica do Congo-Kinshasa',
 u'cf': u'Rep\xfablica Centroafricana',
 u'cg': u'Congo-Brazzaville',
 u'ch': u'Su\xedza',
 u'ci': u'Costa do Marfil',
 u'ck': u'Illas Cook',
 u'cl': u'Chile',
 u'cm': u'Camer\xfan',
 u'cn': u'China',
 u'co': u'Colombia',
 u'cr': u'Costa Rica',
 u'cu': u'Cuba',
 u'cv': u'Cabo Verde',
 u'cx': u'Illa de Christmas',
 u'cy': u'Chipre',
 u'cz': u'Rep\xfablica Checa',
 u'de': u'Alema\xf1a',
 u'dj': u'Djibuti',
 u'dk': u'Dinamarca',
 u'dm': u'Dominica',
 u'do': u'Rep\xfablica Dominicana',
 u'dz': u'Alxeria',
 u'ec': u'Ecuador',
 u'ee': u'Estonia',
 u'eg': u'Exipto',
 u'eh': u'S\xe1hara Occidental',
 u'er': u'Eritrea',
 u'es': u'Espa\xf1a',
 u'et': u'Etiop\xeda',
 u'fi': u'Finlandia',
 u'fj': u'Fixi',
 u'fk': u'Illas Malvinas ou Falkland',
 u'fm': u'Micronesia',
 u'fo': u'Illas Feroe',
 u'fr': u'Francia',
 u'ga': u'Gab\xf3n',
 u'gb': u'Reino Unido',
 u'gd': u'Granada',
 u'ge': u'Xeorxia',
 u'gf': u'G\xfciana Francesa',
 u'gg': u'Guernsey',
 u'gh': u'Gana',
 u'gi': u'Xibraltar',
 u'gl': u'Groenlandia',
 u'gm': u'Gambia',
 u'gn': u'Guinea',
 u'gp': u'Guadalupe',
 u'gq': u'Guinea Ecuatorial',
 u'gr': u'Grecia',
 u'gs': u'Xeorxia do Sur e Illas S\xe1ndwich do Sur',
 u'gt': u'Guatemala',
 u'gu': u'Guam',
 u'gw': u'Guinea-Bissau',
 u'gy': u'G\xfciana',
 u'hk': u'Hong Kong',
 u'hm': u'Illas Heard e McDonald',
 u'hn': u'Honduras',
 u'hr': u'Croacia',
 u'ht': u'Hait\xed',
 u'hu': u'Hungr\xeda',
 u'id': u'Indonesia',
 u'ie': u'Irlanda',
 u'il': u'Israel',
 u'im': u'Illa de Man',
 u'in': u'India',
 u'io': u'Territorio Brit\xe1nico do oc\xe9ano \xcdndico',
 u'iq': u'Iraq',
 u'ir': u'Ir\xe1n',
 u'is': u'Islandia',
 u'it': u'Italia',
 u'je': u'Jersey',
 u'jm': u'Xamaica',
 u'jo': u'Xordania',
 u'jp': u'Xap\xf3n',
 u'ke': u'Kenya',
 u'kg': u'Kirguizist\xe1n',
 u'kh': u'Cambodia',
 u'ki': u'Kiribati',
 u'km': u'Comores',
 u'kn': u'San Cristovo-Nevis',
 u'kp': u'Corea do Norte',
 u'kr': u'Corea do Sur',
 u'kw': u'Kuwait',
 u'ky': u'Illas Caim\xe1n',
 u'kz': u'Kazakhist\xe1n',
 u'la': u'Laosme',
 u'lb': u'L\xedbano',
 u'lc': u'Santa Luc\xeda',
 u'li': u'Liechtenstein',
 u'lk': u'Sri Lanka',
 u'lr': u'Liberia',
 u'ls': u'Lesotho',
 u'lt': u'Lituania',
 u'lu': u'Luxemburgo',
 u'lv': u'Letonia',
 u'ly': u'Libia',
 u'ma': u'Marrocos',
 u'mc': u'M\xf3naco',
 u'md': u'Moldavia',
 u'me': u'Montenegro',
 u'mf': u'Illa de San Marti\xf1o',
 u'mg': u'Madagascar',
 u'mh': u'Illas Marshall',
 u'mk': u'Rep\xfablica de Macedonia',
 u'ml': u'Mal\xed',
 u'mm': u'Myanmar',
 u'mn': u'Mongolia',
 u'mo': u'Macau',
 u'mp': u'Illas Marianas do Norte',
 u'mq': u'Martinica',
 u'mr': u'Mauritania',
 u'ms': u'Montserrat',
 u'mt': u'Malta',
 u'mu': u'Mauricio',
 u'mv': u'Maldivas',
 u'mw': u'Malawi',
 u'mx': u'M\xe9xico',
 u'my': u'Malaisia',
 u'mz': u'Mozambique',
 u'na': u'Namibia',
 u'nc': u'Nova Caledonia',
 u'ne': u'N\xedxer',
 u'nf': u'Illa de Norfolk',
 u'ng': u'Nixeria',
 u'ni': u'Nicaragua',
 u'nl': u'Pa\xedses Baixos',
 u'no': u'Noruega',
 u'np': u'Nepal',
 u'nr': u'Nauruano',
 u'nu': u'Niue',
 u'nz': u'Nova Zelandia',
 u'om': u'Om\xe1n',
 u'pa': u'Panam\xe1',
 u'pe': u'Per\xfa',
 u'pf': u'Polinesia Francesa',
 u'pg': u'Pap\xfaa-Nova Guinea',
 u'ph': u'Filipinas',
 u'pk': u'Paquist\xe1n',
 u'pl': u'Polonia',
 u'pm': u'Saint Pierre e Miquelon',
 u'pn': u'Illas Pitcairn',
 u'pr': u'Porto Rico',
 u'ps': u'Territorio palestino ocupado',
 u'pt': u'Portugal',
 u'pw': u'Palau',
 u'py': u'Paraguai',
 u'qa': u'Qatar',
 u're': u'Reuni\xf3n',
 u'ro': u'Roman\xeda',
 u'rs': u'Serbia',
 u'ru': u'Federaci\xf3n rusa',
 u'rw': u'Ruanda',
 u'sa': u'Arabia Saud\xed',
 u'sb': u'Illas Salom\xf3n',
 u'sc': u'Seicheles',
 u'sd': u'Sud\xe1n',
 u'se': u'Suecia',
 u'sg': u'Singapur',
 u'sh': u'Santa Helena',
 u'si': u'Eslovenia',
 u'sj': u'Svalbard e Jan Mayen',
 u'sk': u'Eslovaquia',
 u'sl': u'Serra Leoa',
 u'sm': u'San Marino',
 u'sn': u'Senegal',
 u'so': u'Somalia',
 u'sr': u'Suriname',
 u'st': u'San Tom\xe9 e Pr\xedncipe',
 u'sv': u'O Salvador',
 u'sy': u'Siria',
 u'sz': u'Suazilandia',
 u'tc': u'Illas Caicos e Turcas',
 u'td': u'Chad',
 u'tf': u'Territorios Franceses do Sur',
 u'tg': u'Togo',
 u'th': u'Tailandia',
 u'tj': u'Taxiquist\xe1n',
 u'tk': u'Tokelau',
 u'tl': u'Timor-Leste',
 u'tm': u'Turkmenist\xe1n',
 u'tn': u'Tunisia',
 u'to': u'Tonga',
 u'tr': u'Turqu\xeda',
 u'tt': u'Trinidad e Tobago',
 u'tv': u'Tuvalu',
 u'tw': u'Taiw\xe1n',
 u'tz': u'Tanzania',
 u'ua': u'Ucra\xedna',
 u'ug': u'Uganda',
 u'um': u'Illas perif\xe9ricas dos Estados Unidos',
 u'us': u'Estados Unidos',
 u'uy': u'Uruguai',
 u'uz': u'Uzbequist\xe1n',
 u'va': u'Cidade do Vaticano',
 u'vc': u'San Vicente e as Granadinas',
 u've': u'Venezuela',
 u'vg': u'Illas Virxes brit\xe1nicas',
 u'vi': u'Illas Virxes americanas',
 u'vn': u'Vietnam',
 u'vu': u'Vanuatu',
 u'wf': u'Wallis e Futuna',
 u'ws': u'Samoa',
 u'ye': u'Iemen',
 u'yt': u'Mayotte',
 u'za': u'Sur\xe1frica',
 u'zm': u'Zambia',
 u'zw': u'Cimbabue'}
